Skip to contents

Code for producing the data is available in run_WGCNA() examples

Usage

data(example_net)

Format

A list including WGCNA module assignments, module eigengenes, dendrogram, input data, sample information, and parameters used

GSE263759