Skip to contents

Code for preparing the data is available in run_Trendy() examples

Usage

data(example_res_list)

Format

A nested list, each element is a list with Trendy results for one group

GSE263759