Plot breakpoint distribution among time points for each group
Arguments
- res_list
A list of the Trendy analysis results, output of
run_Trendy()- group
(Optional) A character vector of group names to be plotted. If NULL, all groups in the input list will be used (default is NULL)
- fontsize
(Optional) Font size for the plot (default is 8)
- ...
Additional arguments to be passed to
Trendy::topTrendy()
Examples
data("example_res_list")
plot_breakpoints(example_res_list)
#> Warning: number of columns of result is not a multiple of vector length (arg 25)
#> Warning: number of columns of result is not a multiple of vector length (arg 19)
#> Warning: number of columns of result is not a multiple of vector length (arg 16)