run_Trendy
R/data.R
example_res_list.Rd
Code for preparing the data is available in run_Trendy() examples
run_Trendy()
data(example_res_list)
A nested list, each element is a list with Trendy results for one group
GSE263759