Get the custom color palette set by set_custom_palette.
If no custom palette has been set, the function will return a default
color palette based on the number of groups specified in the
groups argument.
Examples
get_custom_palette(c("untreated", "IFNbeta"))
#> untreated IFNbeta
#> "#F8766D" "#00BFC4"