Skip to contents

Calculate mean of replicates for each feature at each time point for each group

Usage

merge_replicates(se_obj_list)

Arguments

se_obj_list

A list of SummarizedExperiment objects created by split_groups(), each corresponds to one group of samples.

Value

A list of SummarizedExperiment objects containing the mean of replicates for each feature at each time point for each group. Each object in the list corresponds to one group of samples.

Examples

data("example")
example_obj <- normalise_to_start(example_obj)
example_obj_list <- split_groups(example_obj)
example_obj_merged_list <- merge_replicates(example_obj_list)
example_obj_merged <- merge_groups(example_obj_merged_list)