Split SummarizedExperiment object by groups
Arguments
- se_obj
A SummarizedExperiment object created by
create_input()
Value
A list of SummarizedExperiment objects for each group in the input object. Each object in the list corresponds to one group of samples.
Examples
data(example_obj)
example_obj <- normalise_to_start(example_obj)
#> Normalising to group baseline at each feature's first non-NA time point.
example_obj_list <- split_groups(example_obj)