Skip to contents

Usage

data(tutorial_data)

Format

A data.frame with 500 rows and 41 variables:

Feature

Feature ID, e.g. gene symbols

Sample1, Sample2, ...

Expression values for each sample

GSE263759

Details

Code for preparing the data is available in data-raw/tutorial_input.R

  • Ensembl IDs were mapped to symbols, genes with all zero counts were excluded.

  • Use time 0 untreated samples for other groups' time 0.

  • Include "untreated", "IFNbeta", "IFNgamma", "LPS" groups.

  • Sample 500 random genes.